﻿using System.Globalization;
using System.Windows;
using System.Windows.Media;

namespace TestProject
{
    /// <summary>
    /// 커스텀 타원
    /// </summary>
    public class CustomEllipse : FrameworkElement
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 포맷 텍스트
        /// </summary>
        private FormattedText formattedText;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - CustomEllipse()

        /// <summary>
        /// 생성자
        /// </summary>
        public CustomEllipse()
        {
            this.formattedText = new FormattedText
            (
                "Hello, ellipse!",
                CultureInfo.CurrentCulture,
                FlowDirection,
                new Typeface("Times New Roman Italic"),
                48,
                Brushes.White
            );
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 렌더링시 처리하기 - OnRender(drawingContext)

        /// <summary>
        /// 렌더링시 처리하기
        /// </summary>
        /// <param name="drawingContext">그리기 컨텍스트</param>
        protected override void OnRender(DrawingContext drawingContext)
        {
            drawingContext.DrawEllipse
            (
                Brushes.Blue                                          ,
                new Pen(Brushes.Red, 24)                              ,
                new Point(RenderSize.Width / 2, RenderSize.Height / 2),
                RenderSize.Width  / 2                                 ,
                RenderSize.Height / 2
            );

            drawingContext.PushClip(new RectangleGeometry(new Rect(new Point(0, 0), RenderSize)));

            Point textPoint = new Point
            (
                (RenderSize.Width  - this.formattedText.Width ) / 2,
                (RenderSize.Height - this.formattedText.Height) / 2
            );

            drawingContext.DrawText(this.formattedText, textPoint);
        }

        #endregion
    }
}